<?php
namespace EMS\portalGestor\Service;

use Zeedhi\Framework\Controller\Crud;
use Doctrine\ORM\EntityManager;
use Ems\portalGestor\Util\HcmServices;

use EMS\portalGestor\Util\DateUtil;

class OcorrenciaService extends Crud {

    public function __construct(EntityManager $entityManager, HcmServices $hcmServices) {
        $this->entityManager        = $entityManager;
        $this->hcmServices = $hcmServices;
    }


    public function getOcorrenciasPeriodo(string $nrorg, string $nrvinculom, string $nrperiodoapuracao) {
        try {
            $params = [
                'requestType' => 'Row',
                'row' => [
                    'NRVINCULOM'      => $nrvinculom,
                    'NRPERIODOAPURACAO' => $nrperiodoapuracao,
                    'NRORG'     => $nrorg
                ]
            ];

            $result = $this->hcmServices->send('getOcorrenciasPeriodo', $params, $nrorg, "POST");

            return $result['dataset']['getOcorrenciasPeriodo'];

            /*
            return $this->ocorrenciaRepository->getOcorrenciasPeriodo(
                $nrorg,
                $nrvinculom,
                $nrperiodoapuracao
            );*/
		} catch (\Exception $e) {
			throw $e;
		}
    }

    public function setOcorrenciaFreq($row) {
        try {
            $params = [
                'requestType' => 'Row',
                'row' => $row
            ];

            $result = $this->hcmServices->send('setOcorrenciaFreq', $params, $row['NRORG'],'POST', false);
            return $result;
		} catch (\Exception $e) {
			throw $e;
		}
    }

    public function removeOcorrenciaFreq($row) {
        try {
            $params = [
                'requestType' => 'Row',
                'row' => $row
            ];
            $result = $this->hcmServices->send('removeOcorrenciaFreq', $params, $row['NRORG']);
            return $result;
            //return $this->ocorrenciaRepository->removeOcorrenciaFreq($row);
		} catch (\Exception $e) {
			throw $e;
		}
    }


    public function getOcorrenciasDia($nrOrg, $nrVinculo, $dtinicioprogocor, $cdoperador) {

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRORG'             => $nrOrg,
                'NRVINCULOM'        => $nrVinculo,
                'DTINICIOPROGOCOR'  => $dtinicioprogocor,
                'CDOPERADOR'        => $cdoperador
            ]
        ];

        $result = $this->hcmServices->send('getOcorrenciasDia', $params, $nrOrg);
        $paresMarcacoes = $result['dataset']['getOcorrenciasDia'];

        return $paresMarcacoes;
    }

    public function getTpOcorrencia($nrOrg) {

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRORG'   => $nrOrg
            ]
        ];

        $result = $this->hcmServices->send('getTpOcorrencia', $params, $nrOrg);
        $paresMarcacoes = $result['dataset']['getTpOcorrencia'];

        return $paresMarcacoes;
    }

    public function getMotivoOcorFreq($nrOrg, $cdOperador) {

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRORG'      => $nrOrg,
                'CDOPERADOR' => $cdOperador
            ]
        ];

        $result = $this->hcmServices->send('getMotivoOcorFreq', $params, $nrOrg);
        $paresMarcacoes = $result['dataset']['getMotivoOcorFreq'];

        return $paresMarcacoes;
    }

    public function getOcorrenciasPendentesPeriodoVinculosGestor(
        string $nrorg,
        string $nrestruturam,
        string $nrperiodoapuracao,
        string $cdoperador
    ) {
        $getVinculosDoGestorRoute = 'getOcorrenciasPendentesPeriodoVinculosGestor';

        $result = $this->hcmServices->send(
            $getVinculosDoGestorRoute,
            array(
                'requestType' => 'Row',
                'row' => array(
                    'NRESTRUTURAM'          => $nrestruturam,
                    'NRPERIODOAPURACAO'     => $nrperiodoapuracao,
                    'CDOPERADOR'            => $cdoperador
                )
            ),
            $nrorg
        );

        if (!empty($result['messages'])) {
            throw new \Exception($result['messages'][0]['message']);
        }

        return $result['dataset']['getOcorrenciasPendentesPeriodoVinculosGestor'];
    }

    public function aprovarOcorrencia(
        string $nrorg,
        string $nrprogocorrencia,
        string $cdoperador
    ) {
        $aprovarOcorrenciaRoute = 'aprovarOcorrencia';

        $result = $this->hcmServices->send(
            $aprovarOcorrenciaRoute,
            array(
                'requestType' => 'Row',
                'row' => array(
                    'NRPROGOCORRENCIA'  => $nrprogocorrencia,
                    'CDOPERADOR'        => $cdoperador
                )
            ),
            $nrorg
        );

        if (!empty($result['messages'])) {
            throw new \Exception($result['messages'][0]['message']);
        }

        return $result['dataset']['aprovarOcorrencia'];
    }

    public function rejeitarOcorrencia(
        string $nrorg,
        string $nrprogocorrencia,
        string $cdoperador
    ) {
        $rejeitarOcorrenciaRoute = 'rejeitarOcorrencia';

        $result = $this->hcmServices->send(
            $rejeitarOcorrenciaRoute,
            array(
                'requestType' => 'Row',
                'row' => array(
                    'NRPROGOCORRENCIA'  => $nrprogocorrencia,
                    'CDOPERADOR'        => $cdoperador
                )
            ),
            $nrorg
        );

        if (!empty($result['messages'])) {
            throw new \Exception($result['messages'][0]['message']);
        }

        return $result['dataset']['rejeitarOcorrencia'];
    }

    public function getOcorrenciaFile(
        int $nrOrg,
        int $nrOcorrencia
    ): array {

        $route = 'getOcorrenciaFile';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRORG'            => $nrOrg,
                'NRPROGOCORRENCIA' => $nrOcorrencia
            ]
        ];

        $result = $this->hcmServices->send($route, $params, $nrOrg);
        $file = $result['dataset'][$route];

        return $file;
    }

    public function setOcorrenciasFreq(
        $row
    ): bool {

        $hcmServicesRoute = 'setOcorrenciasFreq';

        $nrOrg = $row['NRORG'];

        $params = [
            'requestType' => 'Row',
            'row' => $row
        ];

        $response = $this->hcmServices->send($hcmServicesRoute, $params, $nrOrg);
        $success = $response['dataset'][$hcmServicesRoute]['success'];

        return $success;
    }

    public function removeOcorrenciasFreq(
        int    $nrOrg,
        int    $nrVinculo,
        array  $dates,
        string $hrMarcacao
    ): bool {

        $hcmServicesRoute = 'removeOcorrenciasFreq';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRORG'         => $nrOrg,
                'NRVINCULOM'    => $nrVinculo,
                'DATE'          => $dates,
                'HORAMARCACAO'  => $hrMarcacao,
            ]
        ];

        $response = $this->hcmServices->send($hcmServicesRoute, $params, $nrOrg);
        $success = $response['dataset'][$hcmServicesRoute]['success'];

        return $success;
    }

    public function removeAlmocos(
        int    $nrOrg,
        int    $nrVinculo,
        array  $dates
    ): bool {

        $hcmServicesRoute = 'removeAlmocos';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRVINCULOM'    => $nrVinculo,
                'DATE'          => $dates,
            ]
        ];

        $response = $this->hcmServices->send($hcmServicesRoute, $params, $nrOrg);
        $success = $response['dataset'][$hcmServicesRoute]['success'];

        return $success;
    }

    public function getEventosAtivos(
        int $nrOrg
    ): array {
        $hcmServicesRoute = 'getEventosAtivos';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'EMPTY' => null,
            ],
        ];

        $response = $this->hcmServices->send($hcmServicesRoute, $params, $nrOrg);
        $eventos = $response['dataset'][$hcmServicesRoute];

        return $eventos;
    }

    public function getDiagnost(
        int $nrOrg
    ): array {
        $hcmServicesRoute = 'getDiagnost';

        $params = [
            'requestType' => 'Row',
            'row' => [],
        ];

        $response = $this->hcmServices->send($hcmServicesRoute, $params, $nrOrg);
        $eventos = $response['dataset'][$hcmServicesRoute];

        return $eventos;
    }

    public function getPessoaConselhoReg(
        int $nrOrg
    ): array {
        $hcmServicesRoute = 'getPessoaConselhoReg';

        $params = [
            'requestType' => 'Row',
            'row' => [],
        ];

        $response = $this->hcmServices->send($hcmServicesRoute, $params, $nrOrg);
        $eventos = $response['dataset'][$hcmServicesRoute];

        return $eventos;
    }

    public function getHoradiah(
        int $nrOrg,
        int $nrPeriodoApuracao = null
    ): array {
        $hcmServicesRoute = 'getHoradiah';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRPERIODOAPURACAO' => $nrPeriodoApuracao,
            ],
        ];

        $response = $this->hcmServices->send($hcmServicesRoute, $params, $nrOrg);
        $eventos = $response['dataset'][$hcmServicesRoute];

        return $eventos;
    }
}
