<?php
namespace Zeedhi\Framework\DataSource\Manager\Mongo;

use \Zeedhi\Framework\DataSource\Configuration as DataSourceConfiguration;

/**
 * Class Configuration
 *
 * @package Zeedhi\Framework\DataSource
 */
class Configuration extends DataSourceConfiguration {

    /** @var Configuration[]  */
    protected $internalCollections = [];
    /** @var array  */
    protected $internalCollectionsOptions = [];
    /** @var Configuration  */
    protected $wrapperCollection;
    /** @var array */
    protected $typesMapping = [];
    /** @var Configuration[] */
    protected static $collectionsMap = [];
    /** @var string */
    protected static $dirLocation;

    /**
     * Sets the wrapper collection.
     *
     * @param string $wrapperCollection The wrapper collection name.
     */
    protected function setWrapperCollection(string $wrapperCollection) {
        $this->wrapperCollection = self::factoryFromFileLocation(self::$dirLocation, $wrapperCollection);
    }

    /**
     * Sets the internal collections.
     *
     * @param array $internalCollections The internal collections.
     */
    protected function setInternalCollections(array $internalCollections) {
        foreach ($internalCollections as $name => $collection) {
            $this->internalCollections[$name] = self::factoryFromFileLocation(self::$dirLocation, $name);
            $this->internalCollectionsOptions[$name] = $collection;
        }
    }

    /**
     * {@inheritDoc}
     */
    protected static function factoryFromJsonData(array $dataSourceConfig, string $dataSourceName) : DataSourceConfiguration {
        /** @var Configuration $instance */
        $instance = parent::factoryFromJsonData($dataSourceConfig, $dataSourceName);
        self::$collectionsMap[$dataSourceName] = $instance;

        $instance->typesMapping = $dataSourceConfig['typesMapping'] ?? $instance->typesMapping;
        $instance->setInternalCollections($dataSourceConfig['internalCollections'] ?? []);
        if (isset($dataSourceConfig['wrapperCollection'])) {
            $instance->setWrapperCollection($dataSourceConfig['wrapperCollection']);
        }
        return $instance;
    }

    /**
     * {@inheritDoc}
     */
    public static function factoryFromFileLocation(string $dirLocation, string $dataSourceName) : DataSourceConfiguration {
        self::$dirLocation = $dirLocation;
        return self::$collectionsMap[$dataSourceName] ?? parent::factoryFromFileLocation($dirLocation, $dataSourceName);
    }

    public function getInternalCollectionOptions(string $name) {
        return $this->internalCollectionsOptions[$name];
    }

    public function getInternalCollections() : array {
        return $this->internalCollections;
    }

    /**
     * Retrieves the internal collection from a field name.
     *
     * @param string $field The field name.
     *
     * @return mixed
     *
     * @throws Exception If no collection was found.
     */
    public function getInternalCollectionForField(string $field) {
        foreach ($this->internalCollectionsOptions as $key => $value) {
            if ($value['fieldName'] === $field) {
                return $this->internalCollections[$key];
            }
        }

        throw Exception::missingInternalCollectionField($field);
    }

    public function getWrapperCollection() {
        return $this->wrapperCollection;
    }

    public function getTypesMapping() : array {
        return $this->typesMapping;
    }

}